@@ -304,11 +304,11 @@ gw_control_load_pdf (GPdfWindow *gpdf_window, const char *uri)
 	Bonobo_PersistFile_load (persist, uri, &ev);
 
 	if (BONOBO_EX (&ev))
-		goto error_stream;
+		goto error_persist_file;
 
 	success = TRUE;		
 
-error_stream:
+error_persist_file:
 	bonobo_object_release_unref (persist, &ev);
 error_persist:
 	CORBA_exception_free (&ev);
@@ -379,13 +379,6 @@ gpdf_window_close (GPdfWindow *gpdf_window)
 		bonobo_main_quit ();
 }
 
-static void
-gw_close_all (void)
-{
-	while (window_list != NULL)
-		gpdf_window_close (GPDF_WINDOW (window_list->data));
-}
-
 static void
 gpdf_window_set_fullscreen (GPdfWindow *gpdf_window, gboolean fullscreen)
 {
@@ -631,13 +624,6 @@ verb_FileClose_cb (BonoboUIComponent *uic, gpointer user_data,
 	gpdf_window_close (GPDF_WINDOW (user_data));
 }
 
-static void
-verb_FileExit_cb (BonoboUIComponent *uic, gpointer user_data,
-		  const char *cname)
-{
-	gw_close_all ();
-}
-
 static void
 listener_ViewFullScreen (BonoboUIComponent *uic, const char *path,
                          Bonobo_UIComponent_EventType type, const char *state,
@@ -709,9 +695,9 @@ verb_HelpAbout_cb (BonoboUIComponent *uic, gpointer user_data,
 			authors [i] = _(authors [i]);
 #endif
 
-		translators = _("translator_credits-PLEASE_ADD_YOURSELF_HERE");
+		translators = _("translator-credits");
 
-		tmp_str = g_strconcat ("Copyright \xc2\xa9 1996-2003 ",
+		tmp_str = g_strconcat ("Copyright \xc2\xa9 1996-2004 ",
 				     _("Glyph & Cog, LLC and authors"),
 				     NULL);
 
@@ -723,7 +709,7 @@ verb_HelpAbout_cb (BonoboUIComponent *uic, gpointer user_data,
 			authors,
 			documenters,
 			(strcmp (translators,
-				 "translator_credits-PLEASE_ADD_YOURSELF_HERE")
+				 "translator-credits")
 			 ? translators : NULL),
 			NULL);
 	
@@ -838,7 +824,6 @@ gw_setup_local_contents (GPdfWindow *gpdf_window)
 static BonoboUIVerb gw_verbs [] = {
 	BONOBO_UI_VERB ("FileOpen",  verb_FileOpen_cb),
 	BONOBO_UI_VERB ("FileClose", verb_FileClose_cb),
-	BONOBO_UI_VERB ("FileExit",  verb_FileExit_cb),
 
 	BONOBO_UI_VERB ("HelpContents", verb_HelpContents_cb),
 	BONOBO_UI_VERB ("HelpAbout", verb_HelpAbout_cb),
