@@ -27,8 +27,6 @@ extern "C" { /* Aargh */
 #include "GlobalParams.h"
 #include "gpdf-stock-icons.h"
 
-static BonoboGenericFactory *factory;
-
 static BonoboObject *
 gpdf_factory (BonoboGenericFactory *factory,
 	      const char *component_id,
@@ -64,12 +62,15 @@ gpdf_factory (BonoboGenericFactory *factory,
 
                 bonobo_object_unref (BONOBO_OBJECT (persist_stream));	
                 bonobo_object_unref (BONOBO_OBJECT (persist_file));	
+		bonobo_control_life_instrument (BONOBO_CONTROL (control));
 
                 return BONOBO_OBJECT (control);        
         } else if (!strcmp (component_id,
                             "OAFIID:GNOME_PDF_NautilusPropertyPage")) {
-                return BONOBO_OBJECT (
+                BonoboControl *control = BONOBO_CONTROL (
                         g_object_new (GPDF_TYPE_NAUTILUS_PROPERTY_PAGE, NULL));
+		bonobo_control_life_instrument (control);
+		return BONOBO_OBJECT (control);
 	} else {
 		g_warning ("Unknown IID %s requested", component_id);
 		return NULL;
